{# The in-page Table of Contents -#}
{% set page_toc = generate_toc_html() -%}
{% if page_toc -%}
<button class="sidebar-toggle secondary-toggle btn btn-sm pst-navbar-icon" title="Toggle secondary sidebar" data-bs-placement="bottom" data-bs-toggle="tooltip">
    <span class="fa-solid fa-list"></span>
</button>
{%- endif %}
