/**
 * sphinx-design extension
 * Improves contrast and readability in dark mode
 * Fixes: https://github.com/executablebooks/sphinx-book-theme/issues/743
 */

// Ensure sphinx-design cards and dropdowns have proper contrast in dark mode
html[data-theme="dark"] {
  .sd-card,
  .sd-dropdown {
    .sd-card-header,
    .sd-card-title,
    .sd-summary-title {
      color: var(--pst-color-text-base);
      text-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
    }
  }
}
